<?php

/**
 * Beispiel-Php-Implementierung der API GetDeliveryInformation zur Verwendung innerhalb eines Web-Services
 * Diese Klasse wird an die WSDL-Datei gebunden mit der Mehtode setClass() der SoapServer-Klasse 
 * Diese Implementierung ist vollstaendig, liefert aber nur Dummy-Daten
 * Daher ist sie als Vorlage fuer die Implementierung eigener Logik fur den WebService geeignet.
 * @author Hayk Matthias, huelsta Werke
 */
Class GetDeliveryInformation {

	const APIVersion 		= "1.10";
	const senderIdIsGLN		= 0;
	const senderIdIsCustNo	= 1;
	
	/**
	 * Methode die fuer den angegebenen Hersteller (recipientGLN) und den angegebenen Programm-Namen (oder herstellerabhaengig auch Programm-Kuerzel)
	 * die Lieferzeit zurueckgibt.
	 * Fehler werden im Attribut errorMsg des Rueckgabe-Objektes zurueckgeliefert. Ansonsten wird dort ein "ok" geliefert falls der Aufruf erfolgreich war.
	 * @author Hayk Matthias, huelsta Werke
	 * @version 1.0
	 * @param senderId				Id des die Information anfordernden Unternehmens. Kann GLN oder Kundennummer sein. Das wird ueber senderIdType signalisiert
	 * @param senderIdType			0(=senderIdIsGLN) senderId ist eine GLN, 1(=senderIsCustNo) senderId ist eine von recipientGLN abhaengige Kundennummer
	 * @param recipientGLN			Hersteller bzw Vertriebsbereich des Herstellers von dem die Lieferzeit erfragt werden soll fuer ein Programm
	 * @param prgName				Programm-Kuerzel fuer welches eine Lieferzeit erfragt wird
	 * @param nameDefinedBySender	true=Den Namen des Programms hat der Sender(=Haendler) definiert, false=Den Name des Programms hat der Empfaenger(=Hersteller) definiert
	 * @return						die Lieferzeit des Programms als Objekt der Klasse DeliveryTime
	 */
	public function getDeliveryTime4PrgName ($parameters)
	{
		$result = new stdClass();
		// Parameter mappen
		$senderId 				= $parameters->senderId;
		$senderIdType			= $parameters->senderIdType;
		$recipientGLN			= $parameters->recipientGLN;
		$prgName				= $parameters->prgName;
		$nameDefinedBySender	= $parameters->nameDefinedBySender;
		
		// ===== Start Datenbeschaffung =========== 
		$dt = new DeliveryTime();
		$dt->setDeliveryTime(99);
		$dt->setTimeKey(DeliveryTime::DeliveryTimeNotYetSupported);
		$dt->setOk(true);
		$dt->setRemark("Remark");
		// $dt->setErrorMsg("Params:senderId=".$senderId.";senderIdType=".$senderIdType.";recipientGLN=".$recipientGLN.";prgName=".$prgName);
		$dt->setErrorMsg($parameters->senderId);
		// ===== Ende Datenbeschaffung ===========
			
		$result->deliveryTime = $dt;
		return $result;
	}


	/**
	 * Methode die fuer den angegebenen Ziel-Hersteller (recipientGLN) und das angegebene Programm
	 * (identifieziert ueber eine GTIN oder ehemals EAN) die Lieferzeit zurueckgibt.
	 * Fehler werden im Attribut errorMsg des Rueckgabe-Objektes zurueckgeliefert. Ansonsten wird dort ein "ok" geliefert falls der Aufruf erfolgreich war.
	 * @author Hayk Matthias, huelsta Werke
	 * @version 1.0
	 * @param senderId		Id des die Information anfordernden Unternehmens. Kann GLN oder Kundennummer sein. Das wird ueber senderIdType signalisiert
	 * @param senderIdType	0(=senderIdIsGLN) senderId ist eine GLN, 1(=senderIsCustNo) senderId ist eine von recipientGLN abhaengige Kundennummer
	 * @param recipientGLN	Hersteller bzw Vertriebsbereich des Herstellers von dem die Lieferzeit erfragt werden soll fuer ein Programm
	 * @param GTIN			GTIN-Nummer des Programms fuer welches eine Lieferzeit erfragt wird. 
	 * @return				Lieferzeit als Objekt der Klasse DeliveryTime
	 */
	public function getDeliveryTime4PrgGTIN ($parameters)
	{
		$result = new stdClass();
		// Parameter mappen
		$senderId 				= $parameters->senderId;
		$senderIdType			= $parameters->senderIdType;
		$recipientGLN			= $parameters->recipientGLN;
		$prgName				= $parameters->prgGTIN;
		
		// ===== Start Datenbeschaffung =========== 
		$dt = new DeliveryTime();
		$dt->setDeliveryTime(99);
		$dt->setTimeKey(DeliveryTime::DeliveryTimeNotYetSupported);
		$dt->setRemark("Remark");
		$dt->setOk(true);
		$dt->setErrorMsg("Only Demo");
		// ===== Ende Datenbeschaffung =========== 
		
		$result->deliveryTime = $dt;
		return $result;
	}

	/**
	 * Methode die fuer den angegebenen Ziel-Hersteller (recipientGLN) alle Programme und Lieferzeiten zurueck liefert.
	 * @author HaykMa, huelsta Werke
	 * @version 1.0
	 * @param senderId		Id des die Information anfordernden Unternehmens. Kann GLN oder Kundennummer sein. Das wird ueber senderIdType signalisiert
	 * @param senderIdType	0(=senderIdIsGLN) senderId ist eine GLN, 1(=senderIsCustNo) senderId ist eine von recipientGLN abhaengige Kundennummer
	 * @param recipientGLN	Hersteller bzw Vertriebsbereich des Herstellers von dem die Lieferzeit erfragt werden soll fuer ein Programm
	 * @return				Liste mit Programm-Informationen. Jeweils Objekte vom Typ ProgramInfo. Die ihrerseits Objekte vom Type DeliveryTime beinhalten
	 * 						Sind Fehler aufgetreten wird (zunaechst) eine leere Liste zurueckgegeben.
	 */
	public function getDeliveryTime4AllPrograms ($parameters)
	{
		$result = new stdClass();
		// Parameter mappen
		$senderId 				= $parameters->senderId;
		$senderIdType			= $parameters->senderIdType;
		$recipientGLN			= $parameters->recipientGLN;
		
		// ===== Start Datenbeschaffung =========== 
		// Dummy-Daten fuer Programm 1
		$pE = new ProgramInformations();
		$p1 = new ProgramInformation();
		$p1->setGtin("1234567890123");
		$p1->setName("PRG1");
		$d1 = new DeliveryTime();
		$d1->setDeliveryTime(10);
		$d1->setTimeKey(DeliveryTime::DeliveryTimeNotYetSupported);
		$d1->setOk(true);
		$d1->setRemark("Remark");
		$d1->setErrorMsg("Only Demo");
		$p1->setDeliveryTime($d1);
		$pE->addProgramInformation($p1);
		
		$p2 = new ProgramInformation();
		$p2->setGtin("2345678901234");
		$p2->setName("PRG2");
		$d2 = new DeliveryTime();
		$d2->setDeliveryTime(11);
		$d2->setTimeKey(DeliveryTime::DeliveryTimeNotYetSupported);
		$d2->setRemark("Remark");
		$d2->setOk(true);
		$d2->setErrorMsg("Only Demo");
		$p2->setDeliveryTime($d2);
		$pE->addProgramInformation($p2);
		// ===== Ende Datenbeschaffung =========== 
		
		// Rueckgabe
		$pE->setOk(true);
		$pE->setErrorMsg("Test-List");
		$result->programInfos = $pE;
		return $result;
	}

	/**
	 * Methode die fuer den angegebenen Ziel-Hersteller (recipientGLN) alle Programme und Programm-Informationen, sowie Lieferzeiten zurueck liefert.
	 * @author HaykMa, huelsta Werke
	 * @version 1.0
	 * @param senderId		Id des die Information anfordernden Unternehmens. Kann GLN oder Kundennummer sein. Das wird ueber senderIdType signalisiert
	 * @param senderIdType	0(=senderIdIsGLN) senderId ist eine GLN, 1(=senderIsCustNo) senderId ist eine von recipientGLN abhaengige Kundennummer
	 * @param recipientGLN	Hersteller bzw Vertriebsbereich des Herstellers von dem die Lieferzeit erfragt werden soll fuer ein Programm
	 * @param lngISO		ISO-Code der Sprache mit dem Text-Informationen zum Programm angefordert werden (z.B. de=Deutsch,en=Englisch)
	 * @return				Liste mit Programm-Informationen. Jeweils Objekte vom Typ ProgramInfo. Die ihrerseits Objekte vom Type DeliveryTime beinhalten
	 * 						Sind Fehler aufgetreten wird (zunaechst) eine leere Liste zurueckgegeben.
	 * @since  1.1
	 * Methode neu zu dieser Version
	 */
	public function getInformations4AllPrograms ($parameters)
	{
		$result = new stdClass();
		// Parameter mappen
		$senderId 				= $parameters->senderId;
		$senderIdType			= $parameters->senderIdType;
		$recipientGLN			= $parameters->recipientGLN;
		$recipientlngISO  = $parameters->lngISO;
		
		// ===== Start Datenbeschaffung =========== 
		// Dummy-Daten fuer Programm 1
		$pE = new ProgramInformations();
		$p1 = new ProgramInformation();
		$p1->setGtin("1234567890123");
		$p1->setName("PRG1");
		$p1->setDescription("Programm 1");
		$d1 = new DeliveryTime();
		$d1->setDeliveryTime(10);
		$d1->setTimeKey(DeliveryTime::DeliveryTimeNotYetSupported);
		$d1->setOk(true);
		$d1->setRemark("Remark");
		$d1->setErrorMsg("Only Demo");
		$p1->setDeliveryTime($d1);
		$pE->addProgramInformation($p1);
		
		$p2 = new ProgramInformation();
		$p2->setGtin("2345678901234");
		$p2->setName("PRG2");
		$p2->setDescription("Programm 2");
		$d2 = new DeliveryTime();
		$d2->setDeliveryTime(11);
		$d2->setTimeKey(DeliveryTime::DeliveryTimeNotYetSupported);
		$d2->setRemark("Remark");
		$d2->setOk(true);
		$d2->setErrorMsg("Only Demo");
		$p2->setDeliveryTime($d2);
		$pE->addProgramInformation($p2);
		// ===== Ende Datenbeschaffung =========== 
		
		// Rueckgabe
		$pE->setOk(true);
		$pE->setErrorMsg("Test-List");
		$result->programInfos = $pE;
		return $result;
	}

	
	/**
	 * Methode die fuer den angegebenen Ziel-Hersteller (recipientGLN) und der angegebenen Auftragsnummer
	 * den Liefertermin zurueckgibt.
	 * Fehler werden im Attribut errorMsg zurueckgeliefert. 
	 * @author Hayk Matthias, huelsta Werke
	 * @param senderId		Id des die Information anfordernden Unternehmens. Kann GLN oder Kundennummer sein. Das wird ueber senderIdType signalisiert
	 * @param senderIdType	0(=senderIdIsGLN) senderId ist eine GLN, 1(=senderIsCustNo) senderId ist eine von recipientGLN abhaengige Kundennummer
	 * @param recipientGLN	Hersteller bzw Vertriebsbereich des Herstellers von dem die Lieferzeit erfragt werden soll fuer ein Programm
	 * @param orderNumber	Auftragsnummer
	 * @return				Lieferdatum als Objekt der Klasse DeliveryDate
	 */
	public function getDeliveryDate4Order ($parameters)
	{
		$result = new stdClass();
		// Parameter mappen
		$senderId 				= $parameters->senderId;
		$senderIdType			= $parameters->senderIdType;
		$recipientGLN			= $parameters->recipientGLN;
		$orderNumber			= $parameters->orderNumber;
		$nameDefinedBySender	= $parameters->nameDefinedBySender;
		
		
		
		// ===== Start Datenbeschaffung =========== 
		$dd = new DeliveryDate();
		$dd->setDeliveryDate("01.01.2011");
		$dd->setDateKey(DeliveryDate::DeliveryDateKeyNotYetSupported);
		$dd->setOk(true);
		$dd->setErrorMsg("Only Demo");
		// ===== Ende Datenbeschaffung =========== 
		
		$result->deliveryDate = $dd;
		return $result;
	}

	/**
	 * Gibt die aktuelle Version der API-Implementierung des Web-Services zurueck
	 * @return	Version
	 */	
	public function getApiVersion ()
	{
		$result = new stdClass();
		// Konstante mit API-Version aus Klassendefinition zurueckgeben
		$result->version = GetDeliveryInformation::APIVersion;
		return $result;
	}
}

/**
 * Klasse mit Lieferzeit-Information. Rueckgaben zu Anfragen bezueglich Lieferzeiten werden als Objekte dieser
 * Klasse zurueckgeliefert.
 * @author Hayk Matthias, huelsta Werke
 */
Class DeliveryTime {

	// Klassen-Konstanten fuer Fehler die die Methoden zurueckliefern 
	const DeliveryTimeKeyError			= -2;
	const DeliveryTimeNotYetSupported 	= -1;
	const DeliveryTimeKeyUnknown		= 0;

	// Klassen-Konstanten fuer die Verwendung des Wertes $deliveryTime
	const DeliveryTimeKeyDays		= 1;
	const DeliveryTimeKeyWeeks		= 2;
	const DeliveryTimeKeyMonths		= 3;

	// Objekt-Properties
	private $deliveryTime;			// Lieferzeit laut Schluessel in $timeKey, der Werte der Konstanten DeliveryTimeKeyDays/Weeks/Months
	private $timeKey;				// Schluessel fuer die Interpretation von $deliveryTime. Ein Wert der Konstanten DeliveryTimeKeyDays/Weeks/Months
	private $ok;					// true=Auswertung war ok, false=Es gab Fehler bei der Auswertung. $errorMsg beachten
	private $remark;				// Zusaetzlicher Kommentar zur Information
	private $errorMsg;				// Fehlermeldung

	// Konstruktor
	public function __construct ()
	{
		$deliveryTime	= 0;
		$timeKey		= DeliveryTime::DeliveryTimeKeyUnknown;
		$ok				= false;
		$remark			= "";
		$errorMsg		= "";
	}

	// Getter- und Setter-Methoden
	public function getDeliveryTime ()
	{
		return $this->deliveryTime;
	}
	public function setDeliveryTime ($deliveryTime)
	{
		$this->deliveryTime = $deliveryTime;
	}

	public function getTimeKey ()
	{
		return $this->timeKey;
	}
	public function setTimeKey ($timeKey)
	{
		$this->timeKey = $timeKey;
	}

	public function isOk ()
	{
		return $this->ok;
	}
	public function setOk ($ok)
	{
		$this->ok = $ok;
	}

	public function getRemark ()
	{
		return $this->remark;
	}
	public function setRemark ($remark)
	{
		$this->remark = $remark;
	}

	public function getErrorMsg ()
	{
		return $this->errorMsg;
	}
	public function setErrorMsg ($errorMsg)
	{
		$this->errorMsg = $errorMsg;
	}


}

/**
 * Klasse mit Informationen zu einem Programm. Enthaelt die (Kurz-)Name und GTIN eines Programms, sowie Daten ueber
 * seine Lieferzeit als Instanz der Klasse DeliveryTime
 * @author Hayk Matthias, huelsta Werke
 *
 */
Class ProgramInformation {

	private $gtin;					// GTIN des Programms. Leer falls das Programm keine GTIN besitzt
	private $name;					// Name des Programms (evt. Kurzform)
	private $deliveryTime;  // Lieferzeit-Objekt
	private $description;  // Langtext

	// Konstruktor
	public function __construct ()
	{
		$this->gtin = "";
		$this->name = "";
		$this->description = "";
		$this->deliveryTime = new DeliveryTime();
	}

	// Getter- und Setter-Methoden
	public function getGtin ()
	{
		return $this->gtin;
	}
	public function setGtin ($gtin)
	{
		$this->gtin = $gtin;
	}
	public function getName ()
	{
		return $this->name;
	}
	public function setName ($name)
	{
		$this->name = $name;
	}
	public function getDeliveryTime ()
	{
		return $this->deliveryTime;
	}
	public function setDeliveryTime ($deliveryTime)
	{
		$this->deliveryTime = $deliveryTime;
	}
	public function getDescription ()
	{
		return $this->description;
	}
	public function setDescription ($description)
	{
		$this->description = $description;
	}
	
}

/**
 * Klasse, die eine Liste von Objektinstanzen vom Typ ProgramInformation, sowie einen ReturnCode und Return-Meldung
 * enthaelt. Diese Klasse wird verwendet um mit einem Aufruf eine Liste von Daten zu holen und gleichzeitig fuer den einen Aufruf
 * einen sauberes Fehlerhandling zu gewaehrleisten
 * @author Hayk Matthias, huelsta Werke
 * @version 1.0
 */
Class ProgramInformations {
	
	private $programInformations;		// Array von einzelnen Instanzen zu ProgramInformation
	private $ok;						// true=Methodenaufruf erfolgreich, false=Fehler bei der Methodenausfuehrung. errMsg beachten
	private $errorMsg;					// Fehlermeldung

	// Konstruktor
	public function __construct ()
	{
		$this->programInformations	= array();
		$this->ok 					= false;
		$this->errorMsg 			= "";
	}
	
	// Getter- und Setter-Methoden
	public function isOk ()
	{
		return $this->ok;
	}
	public function setOk ($ok)
	{
		$this->ok = $ok;
	}

	public function getErrorMsg ()
	{
		return $this->errorMsg;
	}
	public function setErrorMsg ($errorMsg)
	{
		$this->errorMsg = $errorMsg;
	}

	public function addProgramInformation ($pi)
	{
		// array_push($this->programInformations,$pi);
		$this->programInformations[] = $pi;
	}
	
}

/**
 * Klasse mit Informationen zum Lieferdatum eines Auftrages
 * @author Hayk Matthias, huelst Werke
 *
 */
Class DeliveryDate {

	// Konstanten mit Fehlerbedingungen
	const DeliveryDateKeyError			= -2;
	const DeliveryDateKeyNotYetSupported= -1;
	const DeliveryDateKeyUnknown		= 0;

	// Konstanten mit Informationen wie $deliveryDate vom Empfaenger zu interpretieren ist
	const DeliveryDateKey0000YYWW		= 615;
	const DeliveryDateKey00YYYYWW		= 616;
	const DeliveryDateKeyYYYYMMDD		= 102;
	const DeliveryDateKeyYYYYBMMBDD		= 103;

	// Instanz-Variablen
	private $deliveryDate;				// Lieferdatum. Gemaess Kodierung in DeliveryDateKey....
	private $dateKey;					// Schluessel, wie $deliveryDate zu interpretieren ist. Enthaelt obige Konstanten
	private $ok;						// true=Methodenaufruf erfolgreich, false=Fehler bei der Methodenausfuehrung. errMsg beachten
	private $errorMsg;					// Fehlermeldung

	// Konstruktor
	public function __construct ()
	{
		$this->deliveryDate		= "";
		$this->dateKey			= DeliveryDate::DeliveryDateKeyUnknown;

	}

	// Getter- und Setter-Methoden
	public function getDeliveryDate ()
	{
		return $this->deliveryDate;
	}
	public function setDeliveryDate ($deliveryDate)
	{
		$this->deliveryDate = $deliveryDate;
	}

	public function getDateKey ()
	{
		return $this->dateKey;
	}
	public function setDateKey ($dateKey)
	{
		$this->dateKey = $dateKey;
	}

	public function isOk ()
	{
		return $this->ok;
	}
	public function setOk ($ok)
	{
		$this->ok = $ok;
	}

	public function getErrorMsg ()
	{
		return $this->errorMsg;
	}
	public function setErrorMsg ($errorMsg)
	{
		$this->errorMsg = $errorMsg;
	}

}


?>